summaryrefslogtreecommitdiffstats
path: root/perl-install/install/help/help.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/install/help/help.pm')
-rw-r--r--perl-install/install/help/help.pm88
1 files changed, 44 insertions, 44 deletions
diff --git a/perl-install/install/help/help.pm b/perl-install/install/help/help.pm
index 552aa540f..a60aec02f 100644
--- a/perl-install/install/help/help.pm
+++ b/perl-install/install/help/help.pm
@@ -54,7 +54,7 @@ security), choose the desired user and window manager, then click on
\"%s\". If you're not interested in this feature, uncheck the \"%s\" box.", N("User name"), N("Accept user"), N("Next"), N("Advanced"), N("Next"), N("Do you want to use this feature?"));
}
sub ask_mntpoint_s() {
- N("Listed here are the existing Linux partitions detected on your hard drive.
+ N("Listed here are the existing Linux partitions detected on your hard disk drive.
You can keep the choices made by the wizard, since they are good for most
common installations. If you make any changes, you must at least define a
root partition (\"/\"). Do not choose too small a partition or you will not
@@ -64,24 +64,24 @@ separate partition, you will also need to create a \"/home\" partition
Each partition is listed as follows: \"Name\", \"Capacity\".
-\"Name\" is structured: \"hard drive type\", \"hard drive number\",
+\"Name\" is structured: \"hard disk drive type\", \"hard disk drive number\",
\"partition number\" (for example, \"hda1\").
-\"Hard drive type\" is \"hd\" if your hard drive is an IDE hard drive and
-\"sd\" if it is a SCSI hard drive.
+\"Hard drive type\" is \"hd\" if your hard disk drive is an IDE hard disk drive and
+\"sd\" if it is a SCSI hard disk drive.
\"Hard drive number\" is always a letter after \"hd\" or \"sd\". For IDE
-hard drives:
+hard disk drives:
- * \"a\" means \"master hard drive on the primary IDE controller\";
+ * \"a\" means \"master hard disk drive on the primary IDE controller\";
- * \"b\" means \"slave hard drive on the primary IDE controller\";
+ * \"b\" means \"slave hard disk drive on the primary IDE controller\";
- * \"c\" means \"master hard drive on the secondary IDE controller\";
+ * \"c\" means \"master hard disk drive on the secondary IDE controller\";
- * \"d\" means \"slave hard drive on the secondary IDE controller\".
+ * \"d\" means \"slave hard disk drive on the secondary IDE controller\".
-With SCSI hard drives, an \"a\" means \"lowest SCSI ID\", a \"b\" means
+With SCSI hard disk drives, an \"a\" means \"lowest SCSI ID\", a \"b\" means
\"second lowest SCSI ID\", etc.");
}
sub chooseCd() {
@@ -310,31 +310,31 @@ not successful in getting the display configured.", N("No"));
}
sub doPartitionDisks() {
N("You now need to decide where you want to install the Mageia Linux
-operating system on your hard drive. If your hard drive is empty or if an
+operating system on your hard disk drive. If your hard disk drive is empty or if an
existing operating system is using all the available space you will have to
-partition the drive. Basically, partitioning a hard drive means to
+partition the drive. Basically, partitioning a hard disk drive means to
logically divide it to create the space needed to install your new
Mageia Linux system.
-Because the process of partitioning a hard drive is usually irreversible
+Because the process of partitioning a hard disk drive is usually irreversible
and can lead to data losses, partitioning can be intimidating and stressful
for the inexperienced user. Fortunately, DrakX includes a wizard which
simplifies this process. Before continuing with this step, read through the
rest of this section and above all, take your time.
-Depending on the configuration of your hard drive, several options are
+Depending on the configuration of your hard disk drive, several options are
available:
* \"%s\". This option will perform an automatic partitioning of your blank
drive(s). If you use this option there will be no further prompts.
* \"%s\". The wizard has detected one or more existing Linux partitions on
-your hard drive. If you want to use them, choose this option. You will then
+your hard disk drive. If you want to use them, choose this option. You will then
be asked to choose the mount points associated with each of the partitions.
The legacy mount points are selected by default, and for the most part it's
a good idea to keep them.
* \"%s\". If Microsoft Windows is installed on your hard drive and takes
all the space available on it, you will have to create free space for
GNU/Linux. To do so, you can delete your Microsoft Windows partition and
data (see ``Erase entire disk'' solution) or resize your Microsoft Windows
@@ -350,13 +350,13 @@ than when you started. You'll have less free space under Microsoft Windows
to store your data or to install new software.
* \"%s\". If you want to delete all data and all partitions present on
-your hard drive and replace them with your new Mageia Linux system, choose
+your hard disk drive and replace them with your new Mageia Linux system, choose
this option. Be careful, because you will not be able to undo this operation
after you confirm.
!! If you choose this option, all data on your disk will be deleted. !!
* \"%s\". This option appears when the hard drive is entirely taken by
Microsoft Windows. Choosing this option will simply erase everything on the
drive and begin fresh, partitioning everything from scratch.
@@ -457,19 +457,19 @@ sub partition_with_diskdrake() {
N("At this point, you need to choose which partition(s) will be used for the
installation of your Mageia Linux system. If partitions have already been
defined, either from a previous installation of GNU/Linux or by another
-partitioning tool, you can use existing partitions. Otherwise, hard drive
+partitioning tool, you can use existing partitions. Otherwise, hard disk drive
partitions must be defined.
-To create partitions, you must first select a hard drive. You can select
+To create partitions, you must first select a hard disk drive. You can select
the disk for partitioning by clicking on ``hda'' for the first IDE drive,
``hdb'' for the second, ``sda'' for the first SCSI drive and so on.
-To partition the selected hard drive, you can use these options:
+To partition the selected hard disk drive, you can use these options:
- * \"%s\": this option deletes all partitions on the selected hard drive
+ * \"%s\": this option deletes all partitions on the selected hard disk drive
* \"%s\": this option enables you to automatically create ext3 and swap
-partitions in the free space of your hard drive
+partitions in the free space of your hard disk drive
\"%s\": gives access to additional features:
@@ -485,21 +485,21 @@ using this option. Please be careful and remember that it does not always
work.
* \"%s\": discards all changes and reloads the partition table that was
-originally on the hard drive.
+originally on the hard disk drive.
* \"%s\": un-checking this option will force users to manually mount and
unmount removable media such as floppies and CD-ROMs.
* \"%s\": use this option if you wish to use a wizard to partition your
-hard drive. This is recommended if you do not have a good understanding of
+hard disk drive. This is recommended if you do not have a good understanding of
partitioning.
* \"%s\": use this option to cancel your changes.
* \"%s\": allows additional actions on partitions (type, options, format)
-and gives more information about the hard drive.
+and gives more information about the hard disk drive.
- * \"%s\": when you are finished partitioning your hard drive, this will
+ * \"%s\": when you are finished partitioning your hard disk drive, this will
save your changes back to disk.
When defining the size of a partition, you can finely set the partition
@@ -526,34 +526,34 @@ may find it a useful place to store a spare kernel and ramdisk images for
emergency boot situations.", N("Clear all"), N("Auto allocate"), N("More"), N("Save partition table"), N("Restore partition table"), N("Rescue partition table"), N("Reload partition table"), N("Removable media auto-mounting"), N("Wizard"), N("Undo"), N("Toggle between normal/expert mode"), N("Done"));
}
sub resizeFATChoose() {
- N("More than one Microsoft partition has been detected on your hard drive.
+ N("More than one Microsoft partition has been detected on your hard disk drive.
Please choose the one which you want to resize in order to install your new
Mageia Linux operating system.
Each partition is listed as follows: \"Linux name\", \"Windows name\"
\"Capacity\".
-\"Linux name\" is structured: \"hard drive type\", \"hard drive number\",
+\"Linux name\" is structured: \"hard disk drive type\", \"hard disk drive number\",
\"partition number\" (for example, \"hda1\").
-\"Hard drive type\" is \"hd\" if your hard dive is an IDE hard drive and
-\"sd\" if it is a SCSI hard drive.
+\"Hard drive type\" is \"hd\" if your hard dive is an IDE hard disk drive and
+\"sd\" if it is a SCSI hard disk drive.
\"Hard drive number\" is always a letter after \"hd\" or \"sd\". With IDE
-hard drives:
+hard disk drives:
- * \"a\" means \"master hard drive on the primary IDE controller\";
+ * \"a\" means \"master hard disk drive on the primary IDE controller\";
- * \"b\" means \"slave hard drive on the primary IDE controller\";
+ * \"b\" means \"slave hard disk drive on the primary IDE controller\";
- * \"c\" means \"master hard drive on the secondary IDE controller\";
+ * \"c\" means \"master hard disk drive on the secondary IDE controller\";
- * \"d\" means \"slave hard drive on the secondary IDE controller\".
+ * \"d\" means \"slave hard disk drive on the secondary IDE controller\".
-With SCSI hard drives, an \"a\" means \"lowest SCSI ID\", a \"b\" means
+With SCSI hard disk drives, an \"a\" means \"lowest SCSI ID\", a \"b\" means
\"second lowest SCSI ID\", etc.
-\"Windows name\" is the letter of your hard drive under Windows (the first
+\"Windows name\" is the letter of your hard disk drive under Windows (the first
disk or partition is called \"C:\").");
}
sub selectCountry() {
@@ -571,7 +571,7 @@ upgrade of an existing Mageia Linux system:
* \"%s\". For the most part, this completely wipes out the old system.
However, depending on your partitioning scheme, you can prevent some of
your existing data (notably \"home\" directories) from being over-written.
-If you wish to change how your hard drives are partitioned, or to change
+If you wish to change how your hard disk drives are partitioned, or to change
the filesystem, you should use this option.
* \"%s\". This installation class allows you to update the packages
@@ -729,7 +729,7 @@ also scan for one or more PCI SCSI cards on your system. If a SCSI card is
found, DrakX will automatically install the appropriate driver.
Because hardware detection is not foolproof, DrakX may fail in detecting
-your hard drives. If so, you'll have to specify your hardware by hand.
+your hard disk drives. If so, you'll have to specify your hardware by hand.
If you had to manually specify your PCI SCSI adapter, DrakX will ask if you
want to configure options for it. You should allow DrakX to probe the
@@ -809,16 +809,16 @@ on your machine. If you plan to use this machine as a server it's a good
idea to review this setup.", N("Configure"), N("Keyboard"), N("Country / Region"), N("Configure"), N("More"), N("Timezone"), N("Configure"), N("Mouse"), N("Sound card"), N("TV card"), N("Configure"), N("ISDN card"), N("Configure"), N("Graphical Interface"), N("Configure"), N("Network"), N("Proxies"), N("Security Level"), N("Firewall"), N("Bootloader"), N("Services"));
}
sub takeOverHdChoose() {
- N("Choose the hard drive you want to erase in order to install your new
+ N("Choose the hard disk drive you want to erase in order to install your new
Mageia Linux partition. Be careful, all data on this drive will be lost
and will not be recoverable!");
}
sub takeOverHdConfirm() {
N("Click on \"%s\" if you want to delete all data and partitions present on
-this hard drive. Be careful, after clicking on \"%s\", you will not be able
-to recover any data and partitions present on this hard drive, including
+this hard disk drive. Be careful, after clicking on \"%s\", you will not be able
+to recover any data and partitions present on this hard disk drive, including
any Windows data.
Click on \"%s\" to quit this operation without losing data and partitions
-present on this hard drive.", N("Next ->"), N("Next ->"), N("<- Previous"));
+present on this hard disk drive.", N("Next ->"), N("Next ->"), N("<- Previous"));
}
@@ -310,31 +310,31 @@ not successful in getting the display configured.", N("No"));
The legacy mount points are selected by default, and for the most part it's
a good idea to keep them.
- * \"%s\". If Microsoft Windows is installed on your hard drive and takes
+ * \"%s\". If Microsoft Windows is installed on your hard disk drive and takes
all the space available on it, you will have to create free space for
GNU/Linux. To do so, you can delete your Microsoft Windows partition and
@@ -350,13 +350,13 @@ than when you started. You'll have less free space under Microsoft Windows
after you confirm.
!! If you choose this option, all data on your disk will be deleted. !!
- * \"%s\". This option appears when the hard drive is entirely taken by
+ * \"%s\". This option appears when the hard disk drive is entirely taken by
Microsoft Windows. Choosing this option will simply erase everything on the
drive and begin fresh, partitioning everything from scratch.